@@ -16,6 +16,8 @@ except ImportError:
 
     class JsonataContext:
         """Dummy Context for install witout jsonata"""
+        def __init__(self, bigint_patch):
+            pass
         def __call__(self, xform, json_data):
             """We don't want to fail on import, we only want to fail on usage
 
